Please see [https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/install-mlperf-logging-from-src](https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/install-mlperf-logging-from-src) for the documentation of this CM script.
